/* =======================================================================================
   file    : proed4w/setup/EdConfig.p
   by      : jurjen
   purpose : add "Prolint" in Ed4Win to the Build Program titles
             (in menu Tools | Build Setup)
   ======================================================================================= */

MESSAGE "This program will modify your configurations for ED for Windows." SKIP
        "But it won't work if Ed4Win is currently running." SKIP
        "Please make sure that Ed4Win is NOT running at this moment." SKIP(2)
        "If Ed4Win is running now, please close it before you press the OK button."
        VIEW-AS ALERT-BOX.

DEFINE VARIABLE EdConfigFolder  AS CHARACTER NO-UNDO.
DEFINE VARIABLE EdInitials      AS CHARACTER NO-UNDO.
DEFINE VARIABLE EdConfigFile    AS CHARACTER NO-UNDO.
DEFINE VARIABLE EdBackupFile    AS CHARACTER NO-UNDO.
DEFINE VARIABLE cfgline         AS CHARACTER NO-UNDO.
DEFINE VARIABLE EdCurrentTitles AS INTEGER   NO-UNDO.
DEFINE VARIABLE EdExtraTitles   AS INTEGER   NO-UNDO.
DEFINE VARIABLE EdInTitles      AS LOGICAL   NO-UNDO.
DEFINE VARIABLE proed4wExe      AS CHARACTER NO-UNDO.
 
DEFINE STREAM edcfg.
DEFINE STREAM edbackup.

/* find the actual location of proed4w.exe */
FILE-INFO:FILE-NAME = "proed4w/proed4w.exe".
proed4wExe = FILE-INFO:FULL-PATHNAME.
IF proed4wExe=? THEN DO:
   MESSAGE "Can't locate proed4w/proed4w.exe." SKIP 
           "Make sure proed4w is a subdirectory in your Propath and try again."
           VIEW-AS ALERT-BOX.
   RETURN.
END.
IF INDEX(proed4wExe," ")>0 THEN
   proed4wExe = '"' + proed4wExe + '"'.

/* Make a list of buildcommands you like to add to EdConfig */
/* in this case we will add "Prolint" to the .P and .W extensions */
DEFINE TEMP-TABLE tt_buildcommands NO-UNDO 
    FIELD buildcommand AS CHARACTER.

CREATE tt_buildcommands.
ASSIGN tt_buildcommands.buildcommand = SUBSTITUTE('General~tProlint-logwin~tProgress~t&1 -c prolint-logwin~t1~t0~t0~t0~t0~t~t0~t0~t1~t0', proed4wExe).
CREATE tt_buildcommands.
ASSIGN tt_buildcommands.buildcommand = SUBSTITUTE('W~tProlint~tProgress~t&1 -c prolint -f "<NAME>" -cfg setup~t1~t0~t0~t0~t0~t~t0~t0~t1~t0', proed4wExe).
CREATE tt_buildcommands.
ASSIGN tt_buildcommands.buildcommand = SUBSTITUTE('P~tProlint~tProgress~t&1 -c prolint -f "<NAME>" -cfg setup~t1~t0~t0~t0~t0~t~t0~t0~t1~t0', proed4wExe).

/* Determine the name (and location) of the EdConfig file */
LOAD "Software" BASE-KEY "HKEY_CURRENT_USER".
USE "Software".
GET-KEY-VALUE SECTION "Soft As It Gets\ED\Install Details"
    KEY "Config folder" VALUE EdConfigFolder.
GET-KEY-VALUE SECTION "Soft As It Gets\ED\Install Details"
    KEY "initials" VALUE EdInitials.
UNLOAD "Software".

EdConfigFile = EdConfigFolder + "~\EdConfig." + EdInitials.
FILE-INFO:FILE-NAME = EdConfigFile.
IF FILE-INFO:FULL-PATHNAME=? THEN DO:
   MESSAGE "Can't locate the configuration file for Ed4Win." SKIP 
           "(typically named EdConfig.[initials])"
           VIEW-AS ALERT-BOX.
           RETURN.
END.

/* pass 1: read EdConfig, determine the current amount of buildcommands */
EdInTitles = NO.
INPUT STREAM edcfg FROM VALUE(EdConfigFile).
  REPEAT:
     IMPORT STREAM edcfg UNFORMATTED cfgline.
     IF cfgline MATCHES "%%V4BUFFER*" THEN 
        EdInTitles = FALSE.
     IF EdInTitles THEN DO:
        /* don't overwrite existing commands, so see if new commands exist */  
        FIND tt_buildcommands WHERE entry(1,buildcommand,CHR(9))=entry(1,cfgline,CHR(9))
                                AND entry(2,buildcommand,CHR(9))=entry(2,cfgline,CHR(9))
                              NO-ERROR.
        IF AVAILABLE tt_buildcommands THEN
           DELETE tt_buildcommands.
     END.
     IF ENTRY(1,cfgline,CHR(9))="%%V4BUFFER Program Titles" THEN DO:
        EdCurrentTitles = INTEGER(ENTRY(2,cfgline,CHR(9))).
        EdInTitles = TRUE.
     END.
  END.
INPUT STREAM edcfg CLOSE.

IF EdCurrentTitles=0 THEN DO:
    MESSAGE "Found no build commands at all in current version of EdConfig." + EdInitials SKIP
            "That's strange. This setup.p will not continue.."
            VIEW-AS ALERT-BOX.
    RETURN.
END.

EdExtraTitles = 0.
FOR EACH tt_buildcommands :
    EdExtraTitles = EdExtraTitles + 1.
END.
IF EdExtraTitles=0 THEN DO:
   MESSAGE "The specified build commands were already available in EdConfig." + EdInitials SKIP 
           "The config file will not be changed"
           VIEW-AS ALERT-BOX.
   RETURN.
END.

/* create a backup of the EdConfig file */
EdBackupFile = EdConfigFile + ".backup".
OS-COPY VALUE(EdConfigFile) VALUE(EdBackupFile).
FILE-INFO:FILE-NAME = EdBackupFile.
IF FILE-INFO:FULL-PATHNAME=? THEN DO:
   MESSAGE "Can't create a backup of your configuration file," SKIP
           EdBackupFile SKIP
           "This setup.p will not write changes to your configuration file"
           VIEW-AS ALERT-BOX.
   RETURN.
END.

/* pass 2: read backupfile, write configfile */
INPUT STREAM edbackup FROM VALUE(EdBackupFile).
OUTPUT STREAM edcfg TO VALUE(EdConfigFile).
REPEAT:
    IMPORT STREAM edbackup UNFORMATTED cfgline.
    IF ENTRY(1,cfgline,CHR(9))="%%V4BUFFER Program Titles" THEN DO:
       PUT STREAM edcfg UNFORMATTED "%%V4BUFFER Program Titles~t" + STRING(EdExtraTitles + EdCurrentTitles) SKIP.
       FOR EACH tt_buildcommands:
           PUT STREAM edcfg UNFORMATTED buildcommand SKIP.
       END.
    END.
    ELSE DO:
        PUT STREAM edcfg UNFORMATTED cfgline SKIP.
        IF trim(cfgline)="" THEN
           PUT STREAM edcfg SKIP(1).
    END.
END.
OUTPUT STREAM edcfg CLOSE.
INPUT STREAM edbackup CLOSE.

MESSAGE "Done," + STRING(edExtraTitles) + " build titles added to ED for Windows." SKIP(1)
        "Your old configurations are saved in:" SKIP 
        EdBackupFile
        VIEW-AS ALERT-BOX.

