/* ============================================================================
   file    : proed4w/setup/tweaksettings.p
   by      : Jurjen
   purpose : tweaks the files in subdirectory proed4w/settings/setup:
              - adjusts DLC, Propath, working directory
              - replaces database-connections in setup.pf
   ============================================================================ */

define variable vDLC        as character no-undo.
define variable vWorkingDir as character no-undo.
define variable vPropath    as character no-undo.
define variable vInifile    as character no-undo.
define variable i           as integer no-undo.
define variable vLine       as character no-undo.

define temp-table tt_pf no-undo
   field line-num as integer
   field line-txt as character.

/* determine DLC */
vDLC = OS-GETENV("DLC").
IF vDLC=? THEN DO:
   file-info:file-name = "bin~\prowin32.exe".
   vDLC = file-info:full-pathname.
   vDLC = substring(vDLC, 1, length(vDLC) - 17).
END.

/* determine working directory */
file-info:file-name = ".".
vWorkingDir = file-info:full-pathname.

/* determine Propath */
vPropath = PROPATH.

/* import proed4w/settings/setup.pf */
i = 0.
input from value(search("proed4w/settings/setup/setup.pf")).
repeat :
  import unformatted vLine.
  if not (vLine matches "-db *")  then do:
     i = i + 1.
     create tt_pf.
     assign tt_pf.line-num = i
            tt_pf.line-txt = vLine.
  end.
end.
input close.

/* rewrite proed4w/settings/setup.pf,
   deleting all existing -db lines,
   appending startup params for currently connected databases */
output to value (search("proed4w/settings/setup/setup.pf")).
  for each tt_pf by tt_pf.line-num :
     put unformatted tt_pf.line-txt skip.
     if trim(tt_pf.line-txt) = "" then put skip(1).
  end.
  do i=1 to num-dbs :
     vLine = dbparam(i).
     vLine = replace(vLine,",", " ").
     put unformatted vLine skip.
  end.
output close.

/* tweak proed4w.ini */
file-info:file-name = "proed4w/settings/setup/proed4w.ini".
vInifile = file-info:full-pathname.
vLine = vDLC + "\bin\prowin32.exe".
if index(vLine," ")>0 then
   vLine = '"' + vLine + '"'.
run WritePrivateProfileStringA ("startup",
                                "command",
                                vLine,
                                vInifile).
run WritePrivateProfileStringA ("startup",
                                "workingdir",
                                vWorkingdir,
                                vInifile).


/* tweak setup.ini */
file-info:file-name = "proed4w/settings/setup/setup.ini".
vInifile = file-info:full-pathname.
run WritePrivateProfileStringA ("startup",
                                "DLC",
                                vDLC,
                                vInifile).
run WritePrivateProfileStringA ("startup",
                                "PROPATH",
                                vPropath,
                                vInifile).
run WritePrivateProfileStringA ("startup",
                                "EditorConfigPath",
                                vWorkingDir + "\proedit",
                                vInifile).


procedure WritePrivateProfileStringA external "kernel32.dll" :
  define input parameter lpsection  as char.
  define input parameter lpkey      as char.
  define input parameter lpValue    as char.
  define input parameter lpFilename as char.
end procedure.


